complete -c heretek -l gdp-path -d 'Override gdb executable path'
complete -c heretek -s r -l remote -d 'Connect to nc session'
complete -c heretek -l 32 -d 'Switch to 32-bit mode'
complete -c heretek -s c -l cmds -d 'Execute GDB commands'
complete -c heretek -l log -d 'Path to write log (change level in RUST_LOG)'
complete -c heretek -s h -l help -d 'Print help (-h summary)'
complete -c heretek -s V -l version -d 'Print version'
